@@ -16,30 +16,32 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.bigquery_connection_v1.services.connection_service import pagers
-from google.cloud.bigquery_connection_v1.types import connection
-from google.cloud.bigquery_connection_v1.types import connection as gcbc_connection
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
 from google.protobuf import field_mask_pb2  # type: ignore
-from .transports.base import ConnectionServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ConnectionServiceGrpcAsyncIOTransport
+
+from google.cloud.bigquery_connection_v1.services.connection_service import pagers
+from google.cloud.bigquery_connection_v1.types import connection as gcbc_connection
+from google.cloud.bigquery_connection_v1.types import connection
+
 from .client import ConnectionServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, ConnectionServiceTransport
+from .transports.grpc_asyncio import ConnectionServiceGrpcAsyncIOTransport
 
 
 class ConnectionServiceAsyncClient:
@@ -223,9 +225,9 @@ class ConnectionServiceAsyncClient:
 
             from google.cloud import bigquery_connection_v1
 
-            def sample_create_connection():
+            async def sample_create_connection():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_connection_v1.CreateConnectionRequest(
@@ -233,7 +235,7 @@ class ConnectionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.create_connection(request=request)
+                response = await client.create_connection(request=request)
 
                 # Handle the response
                 print(response)
@@ -310,7 +312,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -330,9 +337,9 @@ class ConnectionServiceAsyncClient:
 
             from google.cloud import bigquery_connection_v1
 
-            def sample_get_connection():
+            async def sample_get_connection():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_connection_v1.GetConnectionRequest(
@@ -340,7 +347,7 @@ class ConnectionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_connection(request=request)
+                response = await client.get_connection(request=request)
 
                 # Handle the response
                 print(response)
@@ -411,7 +418,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -431,9 +443,9 @@ class ConnectionServiceAsyncClient:
 
             from google.cloud import bigquery_connection_v1
 
-            def sample_list_connections():
+            async def sample_list_connections():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_connection_v1.ListConnectionsRequest(
@@ -445,7 +457,7 @@ class ConnectionServiceAsyncClient:
                 page_result = client.list_connections(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -516,12 +528,20 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListConnectionsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -542,14 +562,13 @@ class ConnectionServiceAsyncClient:
         reasons, also resets credential if connection properties
         are in the update field mask.
 
-
         .. code-block:: python
 
             from google.cloud import bigquery_connection_v1
 
-            def sample_update_connection():
+            async def sample_update_connection():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_connection_v1.UpdateConnectionRequest(
@@ -557,7 +576,7 @@ class ConnectionServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_connection(request=request)
+                response = await client.update_connection(request=request)
 
                 # Handle the response
                 print(response)
@@ -636,7 +655,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -656,9 +680,9 @@ class ConnectionServiceAsyncClient:
 
             from google.cloud import bigquery_connection_v1
 
-            def sample_delete_connection():
+            async def sample_delete_connection():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = bigquery_connection_v1.DeleteConnectionRequest(
@@ -666,7 +690,7 @@ class ConnectionServiceAsyncClient:
                 )
 
                 # Make the request
-                client.delete_connection(request=request)
+                await client.delete_connection(request=request)
 
         Args:
             request (Union[google.cloud.bigquery_connection_v1.types.DeleteConnectionRequest, dict]):
@@ -728,7 +752,10 @@ class ConnectionServiceAsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     async def get_iam_policy(
@@ -744,22 +771,22 @@ class ConnectionServiceAsyncClient:
         Returns an empty policy if the resource exists and does
         not have a policy set.
 
-
         .. code-block:: python
 
             from google.cloud import bigquery_connection_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_get_iam_policy():
+            async def sample_get_iam_policy():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = bigquery_connection_v1.GetIamPolicyRequest(
+                request = iam_policy_pb2.GetIamPolicyRequest(
                     resource="resource_value",
                 )
 
                 # Make the request
-                response = client.get_iam_policy(request=request)
+                response = await client.get_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -785,21 +812,26 @@ class ConnectionServiceAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -814,17 +846,17 @@ class ConnectionServiceAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -835,11 +867,12 @@ class ConnectionServiceAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -857,7 +890,9 @@ class ConnectionServiceAsyncClient:
         if isinstance(request, dict):
             request = iam_policy_pb2.GetIamPolicyRequest(**request)
         elif not request:
-            request = iam_policy_pb2.GetIamPolicyRequest(resource=resource,)
+            request = iam_policy_pb2.GetIamPolicyRequest(
+                resource=resource,
+            )
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -874,7 +909,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -894,22 +934,22 @@ class ConnectionServiceAsyncClient:
         Can return ``NOT_FOUND``, ``INVALID_ARGUMENT``, and
         ``PERMISSION_DENIED`` errors.
 
-
         .. code-block:: python
 
             from google.cloud import bigquery_connection_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_set_iam_policy():
+            async def sample_set_iam_policy():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = bigquery_connection_v1.SetIamPolicyRequest(
+                request = iam_policy_pb2.SetIamPolicyRequest(
                     resource="resource_value",
                 )
 
                 # Make the request
-                response = client.set_iam_policy(request=request)
+                response = await client.set_iam_policy(request=request)
 
                 # Handle the response
                 print(response)
@@ -935,21 +975,26 @@ class ConnectionServiceAsyncClient:
 
         Returns:
             google.iam.v1.policy_pb2.Policy:
-                Defines an Identity and Access Management (IAM) policy. It is used to
-                   specify access control policies for Cloud Platform
-                   resources.
+                An Identity and Access Management (IAM) policy, which specifies access
+                   controls for Google Cloud resources.
 
                    A Policy is a collection of bindings. A binding binds
-                   one or more members to a single role. Members can be
-                   user accounts, service accounts, Google groups, and
-                   domains (such as G Suite). A role is a named list of
-                   permissions (defined by IAM or configured by users).
-                   A binding can optionally specify a condition, which
-                   is a logic expression that further constrains the
-                   role binding based on attributes about the request
-                   and/or target resource.
+                   one or more members, or principals, to a single role.
+                   Principals can be user accounts, service accounts,
+                   Google groups, and domains (such as G Suite). A role
+                   is a named list of permissions; each role can be an
+                   IAM predefined role or a user-created custom role.
 
-                   **JSON Example**
+                   For some types of Google Cloud resources, a binding
+                   can also specify a condition, which is a logical
+                   expression that allows access to a resource only if
+                   the expression evaluates to true. A condition can add
+                   constraints based on attributes of the request, the
+                   resource, or both. To learn which resources support
+                   conditions in their IAM policies, see the [IAM
+                   documentation](\ https://cloud.google.com/iam/help/conditions/resource-policies).
+
+                   **JSON example:**
 
                       {
                          "bindings": [
@@ -964,17 +1009,17 @@ class ConnectionServiceAsyncClient:
 
                             }, { "role":
                             "roles/resourcemanager.organizationViewer",
-                            "members": ["user:eve@example.com"],
+                            "members": [ "user:eve@example.com" ],
                             "condition": { "title": "expirable access",
                             "description": "Does not grant access after
                             Sep 2020", "expression": "request.time <
                             timestamp('2020-10-01T00:00:00.000Z')", } }
 
-                         ]
+                         ], "etag": "BwWWja0YfJA=", "version": 3
 
                       }
 
-                   **YAML Example**
+                   **YAML example:**
 
                       bindings: - members: - user:\ mike@example.com -
                       group:\ admins@example.com - domain:google.com -
@@ -985,11 +1030,12 @@ class ConnectionServiceAsyncClient:
                       condition: title: expirable access description:
                       Does not grant access after Sep 2020 expression:
                       request.time <
-                      timestamp('2020-10-01T00:00:00.000Z')
+                      timestamp('2020-10-01T00:00:00.000Z') etag:
+                      BwWWja0YfJA= version: 3
 
                    For a description of IAM and its features, see the
-                   [IAM developer's
-                   guide](\ https://cloud.google.com/iam/docs).
+                   [IAM
+                   documentation](\ https://cloud.google.com/iam/docs/).
 
         """
         # Create or coerce a protobuf request object.
@@ -1007,7 +1053,9 @@ class ConnectionServiceAsyncClient:
         if isinstance(request, dict):
             request = iam_policy_pb2.SetIamPolicyRequest(**request)
         elif not request:
-            request = iam_policy_pb2.SetIamPolicyRequest(resource=resource,)
+            request = iam_policy_pb2.SetIamPolicyRequest(
+                resource=resource,
+            )
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1024,7 +1072,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1048,23 +1101,23 @@ class ConnectionServiceAsyncClient:
         authorization checking. This operation may "fail open" without
         warning.
 
-
         .. code-block:: python
 
             from google.cloud import bigquery_connection_v1
+            from google.iam.v1 import iam_policy_pb2  # type: ignore
 
-            def sample_test_iam_permissions():
+            async def sample_test_iam_permissions():
                 # Create a client
-                client = bigquery_connection_v1.ConnectionServiceClient()
+                client = bigquery_connection_v1.ConnectionServiceAsyncClient()
 
                 # Initialize request argument(s)
-                request = bigquery_connection_v1.TestIamPermissionsRequest(
+                request = iam_policy_pb2.TestIamPermissionsRequest(
                     resource="resource_value",
                     permissions=['permissions_value_1', 'permissions_value_2'],
                 )
 
                 # Make the request
-                response = client.test_iam_permissions(request=request)
+                response = await client.test_iam_permissions(request=request)
 
                 # Handle the response
                 print(response)
@@ -1117,7 +1170,8 @@ class ConnectionServiceAsyncClient:
             request = iam_policy_pb2.TestIamPermissionsRequest(**request)
         elif not request:
             request = iam_policy_pb2.TestIamPermissionsRequest(
-                resource=resource, permissions=permissions,
+                resource=resource,
+                permissions=permissions,
             )
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1135,7 +1189,12 @@ class ConnectionServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
