@@ -15,21 +15,21 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
-from google.oauth2 import service_account  # type: ignore
-
-from google.cloud.bigquery_connection_v1.types import connection
-from google.cloud.bigquery_connection_v1.types import connection as gcbc_connection
 from google.iam.v1 import iam_policy_pb2  # type: ignore
 from google.iam.v1 import policy_pb2  # type: ignore
+from google.oauth2 import service_account  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
+import pkg_resources
+
+from google.cloud.bigquery_connection_v1.types import connection as gcbc_connection
+from google.cloud.bigquery_connection_v1.types import connection
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -87,6 +87,7 @@ class ConnectionServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -128,7 +129,9 @@ class ConnectionServiceTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.create_connection: gapic_v1.method.wrap_method(
-                self.create_connection, default_timeout=60.0, client_info=client_info,
+                self.create_connection,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.get_connection: gapic_v1.method.wrap_method(
                 self.get_connection,
@@ -161,7 +164,9 @@ class ConnectionServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.update_connection: gapic_v1.method.wrap_method(
-                self.update_connection, default_timeout=60.0, client_info=client_info,
+                self.update_connection,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_connection: gapic_v1.method.wrap_method(
                 self.delete_connection,
@@ -179,10 +184,14 @@ class ConnectionServiceTransport(abc.ABC):
                 client_info=client_info,
             ),
             self.get_iam_policy: gapic_v1.method.wrap_method(
-                self.get_iam_policy, default_timeout=60.0, client_info=client_info,
+                self.get_iam_policy,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.set_iam_policy: gapic_v1.method.wrap_method(
-                self.set_iam_policy, default_timeout=60.0, client_info=client_info,
+                self.set_iam_policy,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.test_iam_permissions: gapic_v1.method.wrap_method(
                 self.test_iam_permissions,
@@ -194,9 +203,9 @@ class ConnectionServiceTransport(abc.ABC):
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -278,5 +287,9 @@ class ConnectionServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("ConnectionServiceTransport",)
